#include "gudev.gen.h"
#include "_cgo_export.h"

static void _c_callback_cleanup(void *userdata)
{
	_GUdev_go_callback_cleanup(userdata);
}

extern void _GBaseFinalizeFunc_c_wrapper();
extern void _GBaseFinalizeFunc_c_wrapper_once();
extern void _GBaseInitFunc_c_wrapper();
extern void _GBaseInitFunc_c_wrapper_once();
extern void _GBindingTransformFunc_c_wrapper();
extern void _GBindingTransformFunc_c_wrapper_once();
extern void _GBoxedCopyFunc_c_wrapper();
extern void _GBoxedCopyFunc_c_wrapper_once();
extern void _GBoxedFreeFunc_c_wrapper();
extern void _GBoxedFreeFunc_c_wrapper_once();
extern void _GCallback_c_wrapper();
extern void _GCallback_c_wrapper_once();
extern void _GClassFinalizeFunc_c_wrapper();
extern void _GClassFinalizeFunc_c_wrapper_once();
extern void _GClassInitFunc_c_wrapper();
extern void _GClassInitFunc_c_wrapper_once();
extern void _GClosureMarshal_c_wrapper();
extern void _GClosureMarshal_c_wrapper_once();
extern void _GClosureNotify_c_wrapper();
extern void _GClosureNotify_c_wrapper_once();
extern void _GInstanceInitFunc_c_wrapper();
extern void _GInstanceInitFunc_c_wrapper_once();
extern void _GInterfaceFinalizeFunc_c_wrapper();
extern void _GInterfaceFinalizeFunc_c_wrapper_once();
extern void _GInterfaceInitFunc_c_wrapper();
extern void _GInterfaceInitFunc_c_wrapper_once();
extern void _GObjectFinalizeFunc_c_wrapper();
extern void _GObjectFinalizeFunc_c_wrapper_once();
extern void _GObjectGetPropertyFunc_c_wrapper();
extern void _GObjectGetPropertyFunc_c_wrapper_once();
extern void _GObjectSetPropertyFunc_c_wrapper();
extern void _GObjectSetPropertyFunc_c_wrapper_once();
extern void _GSignalAccumulator_c_wrapper();
extern void _GSignalAccumulator_c_wrapper_once();
extern void _GSignalEmissionHook_c_wrapper();
extern void _GSignalEmissionHook_c_wrapper_once();
extern void _GToggleNotify_c_wrapper();
extern void _GToggleNotify_c_wrapper_once();
extern void _GTypeClassCacheFunc_c_wrapper();
extern void _GTypeClassCacheFunc_c_wrapper_once();
extern void _GTypeInterfaceCheckFunc_c_wrapper();
extern void _GTypeInterfaceCheckFunc_c_wrapper_once();
extern void _GTypePluginCompleteInterfaceInfo_c_wrapper();
extern void _GTypePluginCompleteInterfaceInfo_c_wrapper_once();
extern void _GTypePluginCompleteTypeInfo_c_wrapper();
extern void _GTypePluginCompleteTypeInfo_c_wrapper_once();
extern void _GTypePluginUnuse_c_wrapper();
extern void _GTypePluginUnuse_c_wrapper_once();
extern void _GTypePluginUse_c_wrapper();
extern void _GTypePluginUse_c_wrapper_once();
extern void _GValueTransform_c_wrapper();
extern void _GValueTransform_c_wrapper_once();
extern void _GWeakNotify_c_wrapper();
extern void _GWeakNotify_c_wrapper_once();
extern void _GChildWatchFunc_c_wrapper();
extern void _GChildWatchFunc_c_wrapper_once();
extern void _GClearHandleFunc_c_wrapper();
extern void _GClearHandleFunc_c_wrapper_once();
extern void _GCompareDataFunc_c_wrapper();
extern void _GCompareDataFunc_c_wrapper_once();
extern void _GCompareFunc_c_wrapper();
extern void _GCompareFunc_c_wrapper_once();
extern void _GCopyFunc_c_wrapper();
extern void _GCopyFunc_c_wrapper_once();
extern void _GDataForeachFunc_c_wrapper();
extern void _GDataForeachFunc_c_wrapper_once();
extern void _GDestroyNotify_c_wrapper();
extern void _GDestroyNotify_c_wrapper_once();
extern void _GDuplicateFunc_c_wrapper();
extern void _GDuplicateFunc_c_wrapper_once();
extern void _GEqualFunc_c_wrapper();
extern void _GEqualFunc_c_wrapper_once();
extern void _GFreeFunc_c_wrapper();
extern void _GFreeFunc_c_wrapper_once();
extern void _GFunc_c_wrapper();
extern void _GFunc_c_wrapper_once();
extern void _GHFunc_c_wrapper();
extern void _GHFunc_c_wrapper_once();
extern void _GHRFunc_c_wrapper();
extern void _GHRFunc_c_wrapper_once();
extern void _GHashFunc_c_wrapper();
extern void _GHashFunc_c_wrapper_once();
extern void _GHookCheckFunc_c_wrapper();
extern void _GHookCheckFunc_c_wrapper_once();
extern void _GHookCheckMarshaller_c_wrapper();
extern void _GHookCheckMarshaller_c_wrapper_once();
extern void _GHookCompareFunc_c_wrapper();
extern void _GHookCompareFunc_c_wrapper_once();
extern void _GHookFinalizeFunc_c_wrapper();
extern void _GHookFinalizeFunc_c_wrapper_once();
extern void _GHookFindFunc_c_wrapper();
extern void _GHookFindFunc_c_wrapper_once();
extern void _GHookFunc_c_wrapper();
extern void _GHookFunc_c_wrapper_once();
extern void _GHookMarshaller_c_wrapper();
extern void _GHookMarshaller_c_wrapper_once();
extern void _GIOFunc_c_wrapper();
extern void _GIOFunc_c_wrapper_once();
extern void _GLogFunc_c_wrapper();
extern void _GLogFunc_c_wrapper_once();
extern void _GLogWriterFunc_c_wrapper();
extern void _GLogWriterFunc_c_wrapper_once();
extern void _GNodeForeachFunc_c_wrapper();
extern void _GNodeForeachFunc_c_wrapper_once();
extern void _GNodeTraverseFunc_c_wrapper();
extern void _GNodeTraverseFunc_c_wrapper_once();
extern void _GOptionArgFunc_c_wrapper();
extern void _GOptionArgFunc_c_wrapper_once();
extern void _GOptionErrorFunc_c_wrapper();
extern void _GOptionErrorFunc_c_wrapper_once();
extern void _GOptionParseFunc_c_wrapper();
extern void _GOptionParseFunc_c_wrapper_once();
extern void _GPollFunc_c_wrapper();
extern void _GPollFunc_c_wrapper_once();
extern void _GPrintFunc_c_wrapper();
extern void _GPrintFunc_c_wrapper_once();
extern void _GRegexEvalCallback_c_wrapper();
extern void _GRegexEvalCallback_c_wrapper_once();
extern void _GScannerMsgFunc_c_wrapper();
extern void _GScannerMsgFunc_c_wrapper_once();
extern void _GSequenceIterCompareFunc_c_wrapper();
extern void _GSequenceIterCompareFunc_c_wrapper_once();
extern void _GSourceDisposeFunc_c_wrapper();
extern void _GSourceDisposeFunc_c_wrapper_once();
extern void _GSourceDummyMarshal_c_wrapper();
extern void _GSourceDummyMarshal_c_wrapper_once();
extern void _GSourceFunc_c_wrapper();
extern void _GSourceFunc_c_wrapper_once();
extern void _GSpawnChildSetupFunc_c_wrapper();
extern void _GSpawnChildSetupFunc_c_wrapper_once();
extern void _GTestDataFunc_c_wrapper();
extern void _GTestDataFunc_c_wrapper_once();
extern void _GTestFixtureFunc_c_wrapper();
extern void _GTestFixtureFunc_c_wrapper_once();
extern void _GTestFunc_c_wrapper();
extern void _GTestFunc_c_wrapper_once();
extern void _GTestLogFatalFunc_c_wrapper();
extern void _GTestLogFatalFunc_c_wrapper_once();
extern void _GThreadFunc_c_wrapper();
extern void _GThreadFunc_c_wrapper_once();
extern void _GTranslateFunc_c_wrapper();
extern void _GTranslateFunc_c_wrapper_once();
extern void _GTraverseFunc_c_wrapper();
extern void _GTraverseFunc_c_wrapper_once();
extern void _GUnixFDSourceFunc_c_wrapper();
extern void _GUnixFDSourceFunc_c_wrapper_once();
extern void _GVoidFunc_c_wrapper();
extern void _GVoidFunc_c_wrapper_once();
